<hr class="d-lg-none"/>

<ul class="navbar-nav flex-row flex-wrap">

    <li class="nav-item dropdown">
     <button aria-expanded="false" data-bs-display="static" data-bs-toggle="dropdown" id="dmvc-theme" type="button"
             class="btn btn-link nav-link py-2 px-0 px-lg-2 dropdown-toggle d-flex align-items-center">
      <svg class="bi my-1 theme-icon-active">
       <use href="#sun-fill">
       </use>
      </svg>
      <span class="d-lg-none ms-2">
       Toggle theme
      </span>
     </button>
     <ul aria-labelledby="dmvc-theme" class="dropdown-menu dropdown-menu-end" style="--bs-dropdown-min-width: 8rem;">
      <li>
       <button class="dropdown-item d-flex align-items-center active" data-bs-theme-value="light" type="button">
        <svg class="bi me-2 opacity-50 theme-icon">
         <use href="#sun-fill">
         </use>
        </svg>
        Light
        <svg class="bi ms-auto d-none">
         <use href="#check2">
         </use>
        </svg>
       </button>
      </li>
      <li>
       <button class="dropdown-item d-flex align-items-center" data-bs-theme-value="dark" type="button">
        <svg class="bi me-2 opacity-50 theme-icon">
         <use href="#moon-stars-fill">
         </use>
        </svg>
        Dark
        <svg class="bi ms-auto d-none">
         <use href="#check2">
         </use>
        </svg>
       </button>
      </li>
      <li>
       <button class="dropdown-item d-flex align-items-center" data-bs-theme-value="auto" type="button">
        <svg class="bi me-2 opacity-50 theme-icon">
         <use href="#circle-half">
         </use>
        </svg>
        Auto
        <svg class="bi ms-auto d-none">
         <use href="#check2">
         </use>
        </svg>
       </button>
      </li>
     </ul>
    </li>
</ul>