{% extends 'static_pages/templates/_base.html' %}

{% block page_title %}User Dashboard | {% endblock %}
{% block meta_description %}User logged in dashboard.{% endblock %}

{% block content %}

<div class="container mt-5">
    <div class="row justify-content-center">
        <div class="col-md-6">
            <div class="card">
                <div class="card-body">
                    You're logged in as {{ user.username }}.<br> 
                    <a href="/^{obj}^/logout">Logout</a>
                </div>
            </div>
        </div>
    </div>
</div>

{% endblock %}