                        <label for="^{f}^">^{F}^</label><br>
                        <input type="text" name="^{f}^" class="form-control" value="{{ vals.get('^{f}^', '') }}"><br>
                        