{% extends 'static_pages/templates/_base.html' %}

{% block page_title %}^{Obj}^ | {% endblock %}
{% block meta_description %}View a single ^{Obj}^ record.{% endblock %}

{% block content %}

<div class="container mt-5">
    <a href="/^{obj}^" class="btn btn-sm btn-primary">Back</a>
    <div class="card mt-3">
        <ul class="list-group list-group-flush">
            {% for k, v in ^{obj}^.dict().items() %}
            <li class="list-group-item"><b>{{ k }}</b> {{ v | safe }}</li>
            {% endfor %}
        </ul>
        <div class="card-body">
            <a href="/^{obj}^/edit/{{ ^{obj}^.key }}" class="btn btn-sm btn-warning">Edit</a>
            <a href="/^{obj}^/delete/{{ ^{obj}^.key }}" class="btn btn-sm btn-danger">Delete</a>
        </div>
    </div>
</div>

{% endblock %}